Struct archive::archive::Archive

source ·
pub struct Archive<'a, W>where
    W: Write + Seek,{ /* private fields */ }

Implementations

source

impl<'a, W> Archive<'a, W>where W: Write + Seek,

source

pub fn new( writer: W, compressor: Box<dyn Compress + 'a>, compression_type: Compression ) -> Result<Self>

source

pub fn add_path<P: AsRef<Path>>( &mut self, path: &OsStr, file_path: P ) -> Result<()>

add a path record

path will be stored in the archive directly, while file_path is the actual path of the file to be added

For example, now we are at the location ‘/tmp’, and if we do

tar -C /home -c user > ./tar

the stored paths in this tarball will like this:

  • user/a.txt
  • user/b.txt

But they’re not relative to our current location ‘/tmp’, so we also need paths to these files to be added, just using absolute paths:

  • /home/user/a.txt
  • /home/user/b.txt

like tar utility

source

pub fn set_info(&mut self, info: &Info)

source

pub fn write(&mut self) -> Result<()>

source

pub fn flush(&mut self) -> Result<()>